[libvirt] [PATCH 09/22] pci: rename virPCIDeviceGetVFIOGroupDev to virPCIDeviceGetIOMMUGroupDev

Laine Stump laine at laine.org
Mon Jun 24 09:54:58 UTC 2013


I realized after the fact that it's probably better in the long run to
give this function a name that matches the name of the link used in
sysfs to hold the group (iommu_group).

I'm changing it now because I'm about to add several more functions
that deal with iommu groups.
---
 src/libvirt_private.syms         | 2 +-
 src/qemu/qemu_cgroup.c           | 4 ++--
 src/security/security_apparmor.c | 2 +-
 src/security/security_dac.c      | 4 ++--
 src/security/security_selinux.c  | 4 ++--
 src/util/virpci.c                | 6 +++---
 src/util/virpci.h                | 2 +-
 7 files changed, 12 insertions(+), 12 deletions(-)

diff --git a/src/libvirt_private.syms b/src/libvirt_private.syms
index 2fdb185..b7a59ec 100644
--- a/src/libvirt_private.syms
+++ b/src/libvirt_private.syms
@@ -1652,6 +1652,7 @@ virPCIDeviceCopy;
 virPCIDeviceDetach;
 virPCIDeviceFileIterate;
 virPCIDeviceFree;
+virPCIDeviceGetIOMMUGroupDev;
 virPCIDeviceGetManaged;
 virPCIDeviceGetName;
 virPCIDeviceGetRemoveSlot;
@@ -1659,7 +1660,6 @@ virPCIDeviceGetReprobe;
 virPCIDeviceGetStubDriver;
 virPCIDeviceGetUnbindFromStub;
 virPCIDeviceGetUsedBy;
-virPCIDeviceGetVFIOGroupDev;
 virPCIDeviceIsAssignable;
 virPCIDeviceListAdd;
 virPCIDeviceListCount;
diff --git a/src/qemu/qemu_cgroup.c b/src/qemu/qemu_cgroup.c
index cf46993..5f54ca6 100644
--- a/src/qemu/qemu_cgroup.c
+++ b/src/qemu/qemu_cgroup.c
@@ -277,7 +277,7 @@ qemuSetupHostdevCGroup(virDomainObjPtr vm,
                 if (!pci)
                     goto cleanup;
 
-                if (!(path = virPCIDeviceGetVFIOGroupDev(pci)))
+                if (!(path = virPCIDeviceGetIOMMUGroupDev(pci)))
                     goto cleanup;
 
                 VIR_DEBUG("Cgroup allow %s for PCI device assignment", path);
@@ -376,7 +376,7 @@ qemuTeardownHostdevCgroup(virDomainObjPtr vm,
                 if (!pci)
                     goto cleanup;
 
-                if (!(path = virPCIDeviceGetVFIOGroupDev(pci)))
+                if (!(path = virPCIDeviceGetIOMMUGroupDev(pci)))
                     goto cleanup;
 
                 VIR_DEBUG("Cgroup deny %s for PCI device assignment", path);
diff --git a/src/security/security_apparmor.c b/src/security/security_apparmor.c
index 87c2777..50b0e74 100644
--- a/src/security/security_apparmor.c
+++ b/src/security/security_apparmor.c
@@ -823,7 +823,7 @@ AppArmorSetSecurityHostdevLabel(virSecurityManagerPtr mgr,
 
         if (dev->source.subsys.u.pci.backend
             == VIR_DOMAIN_HOSTDEV_PCI_BACKEND_VFIO) {
-            char *vfioGroupDev = virPCIDeviceGetVFIOGroupDev(pci);
+            char *vfioGroupDev = virPCIDeviceGetIOMMUGroupDev(pci);
 
             if (!vfioGroupDev) {
                 virPCIDeviceFree(pci);
diff --git a/src/security/security_dac.c b/src/security/security_dac.c
index b8d1a92..0d6defc 100644
--- a/src/security/security_dac.c
+++ b/src/security/security_dac.c
@@ -529,7 +529,7 @@ virSecurityDACSetSecurityHostdevLabel(virSecurityManagerPtr mgr,
 
         if (dev->source.subsys.u.pci.backend
             == VIR_DOMAIN_HOSTDEV_PCI_BACKEND_VFIO) {
-            char *vfioGroupDev = virPCIDeviceGetVFIOGroupDev(pci);
+            char *vfioGroupDev = virPCIDeviceGetIOMMUGroupDev(pci);
 
             if (!vfioGroupDev) {
                 virPCIDeviceFree(pci);
@@ -648,7 +648,7 @@ virSecurityDACRestoreSecurityHostdevLabel(virSecurityManagerPtr mgr,
 
         if (dev->source.subsys.u.pci.backend
             == VIR_DOMAIN_HOSTDEV_PCI_BACKEND_VFIO) {
-            char *vfioGroupDev = virPCIDeviceGetVFIOGroupDev(pci);
+            char *vfioGroupDev = virPCIDeviceGetIOMMUGroupDev(pci);
 
             if (!vfioGroupDev) {
                 virPCIDeviceFree(pci);
diff --git a/src/security/security_selinux.c b/src/security/security_selinux.c
index 6fe063e..7802dda 100644
--- a/src/security/security_selinux.c
+++ b/src/security/security_selinux.c
@@ -1333,7 +1333,7 @@ virSecuritySELinuxSetSecurityHostdevSubsysLabel(virDomainDefPtr def,
 
         if (dev->source.subsys.u.pci.backend
             == VIR_DOMAIN_HOSTDEV_PCI_BACKEND_VFIO) {
-            char *vfioGroupDev = virPCIDeviceGetVFIOGroupDev(pci);
+            char *vfioGroupDev = virPCIDeviceGetIOMMUGroupDev(pci);
 
             if (!vfioGroupDev) {
                 virPCIDeviceFree(pci);
@@ -1528,7 +1528,7 @@ virSecuritySELinuxRestoreSecurityHostdevSubsysLabel(virSecurityManagerPtr mgr,
 
         if (dev->source.subsys.u.pci.backend
             == VIR_DOMAIN_HOSTDEV_PCI_BACKEND_VFIO) {
-            char *vfioGroupDev = virPCIDeviceGetVFIOGroupDev(pci);
+            char *vfioGroupDev = virPCIDeviceGetIOMMUGroupDev(pci);
 
             if (!vfioGroupDev) {
                 virPCIDeviceFree(pci);
diff --git a/src/util/virpci.h b/src/util/virpci.h
index 944aa09..89717b8 100644
--- a/src/util/virpci.h
+++ b/src/util/virpci.h
@@ -117,7 +117,7 @@ int virPCIDeviceFileIterate(virPCIDevicePtr dev,
                             virPCIDeviceFileActor actor,
                             void *opaque);
 char *
-virPCIDeviceGetVFIOGroupDev(virPCIDevicePtr dev);
+virPCIDeviceGetIOMMUGroupDev(virPCIDevicePtr dev);
 
 int virPCIDeviceIsAssignable(virPCIDevicePtr dev,
                              int strict_acs_check);
diff --git a/src/util/virpci.c b/src/util/virpci.c
index 2a77e77..23cff09 100644
--- a/src/util/virpci.c
+++ b/src/util/virpci.c
@@ -1861,11 +1861,11 @@ cleanup:
     return ret;
 }
 
 /* virPCIDeviceGetVFIOGroupDev - return the name of the device used to
  * control this PCI device's group (e.g. "/dev/vfio/15")
  */
 char *
-virPCIDeviceGetVFIOGroupDev(virPCIDevicePtr dev)
+virPCIDeviceGetIOMMUGroupDev(virPCIDevicePtr dev)
 {
     char *devPath = NULL;
     char *groupPath = NULL;
@@ -1861,11 +1861,11 @@ cleanup:
 }
 
-/* virPCIDeviceGetVFIOGroupDev - return the name of the device used to
- * control this PCI device's group (e.g. "/dev/vfio/15")
+/* virPCIDeviceGetIOMMUGroupDev - return the name of the device used
+ * to control this PCI device's group (e.g. "/dev/vfio/15")
  */
 char *
-- 
1.7.11.7




More information about the libvir-list mailing list